@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2009 Nick Schermer <nick@xfce.org>
+ * Copyright (C) 2008-2010 Nick Schermer <nick@xfce.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,7 +19,7 @@
 #ifndef __LIBXFCE4PANEL__
 #define __LIBXFCE4PANEL__
 
-G_BEGIN_DECLS
+#include <gtk/gtk.h>
 
 #define LIBXFCE4PANEL_INSIDE_LIBXFCE4PANEL_H
 
@@ -27,15 +27,11 @@ G_BEGIN_DECLS
 #include <libxfce4panel/libxfce4panel-enums.h>
 #include <libxfce4panel/libxfce4panel-enum-types.h>
 #include <libxfce4panel/xfce-panel-macros.h>
-#include <libxfce4panel/xfce-panel-macros-46.h>
 #include <libxfce4panel/xfce-arrow-button.h>
-#include <libxfce4panel/xfce-hvbox.h>
 #include <libxfce4panel/xfce-panel-convenience.h>
 #include <libxfce4panel/xfce-panel-plugin.h>
 #include <libxfce4panel/xfce-panel-image.h>
 
 #undef LIBXFCE4PANEL_INSIDE_LIBXFCE4PANEL_H
 
-G_END_DECLS
-
 #endif /* !__LIBXFCE4PANEL__ */
