@@ -125,6 +125,17 @@ xfce_panel_plugin_provider_set_icon_size (XfcePanelPluginProvider *provider,
 
 
 
+void
+xfce_panel_plugin_provider_set_dark_mode (XfcePanelPluginProvider *provider,
+                                          gboolean                 dark_mode)
+{
+  panel_return_if_fail (XFCE_IS_PANEL_PLUGIN_PROVIDER (provider));
+
+  (*XFCE_PANEL_PLUGIN_PROVIDER_GET_INTERFACE (provider)->set_dark_mode) (provider, dark_mode);
+}
+
+
+
 void
 xfce_panel_plugin_provider_set_mode (XfcePanelPluginProvider *provider,
                                      XfcePanelPluginMode      mode)
