@@ -74,7 +74,6 @@ struct _SnItem
   GCancellable        *cancellable;
   GDBusProxy          *item_proxy;
   GDBusProxy          *properties_proxy;
-  guint                properties_timeout;
 
   gchar               *bus_name;
   gchar               *object_path;
@@ -148,10 +147,11 @@ if (error != NULL) \
 
 
 
-#define return_and_finish_if_true(condition) \
+#define finish_and_return_if_true(condition) \
 if (condition) \
   { \
-    g_signal_emit (G_OBJECT (item), sn_item_signals[FINISH], 0); \
+    if (G_IS_OBJECT (item)) \
+      g_signal_emit (item, sn_item_signals[FINISH], 0); \
     return; \
   }
 
@@ -252,7 +252,6 @@ sn_item_init (SnItem *item)
   item->cancellable = g_cancellable_new ();
   item->item_proxy = NULL;
   item->properties_proxy = NULL;
-  item->properties_timeout = 0;
 
   item->bus_name = NULL;
   item->object_path = NULL;
@@ -289,9 +288,6 @@ sn_item_finalize (GObject *object)
 
   g_object_unref (item->cancellable);
 
-  if (item->properties_timeout != 0)
-    g_source_remove (item->properties_timeout);
-
   if (item->properties_proxy != NULL)
     g_object_unref (item->properties_proxy);
 
@@ -390,7 +386,7 @@ sn_item_set_property (GObject      *object,
 
 
 static void
-sn_item_subscription_context_ubsubscribe (gpointer  data,
+sn_item_subscription_context_unsubscribe (gpointer  data,
                                           GObject  *where_the_object_was)
 {
   SubscriptionContext *context = data;
@@ -418,7 +414,7 @@ sn_item_name_owner_changed (GDBusConnection *connection,
   finish = new_owner == NULL || strlen (new_owner) == 0;
   g_free (new_owner);
 
-  return_and_finish_if_true (finish);
+  finish_and_return_if_true (finish);
 }
 
 
@@ -432,8 +428,10 @@ sn_item_properties_callback (GObject      *source_object,
   GError *error = NULL;
 
   item->properties_proxy = g_dbus_proxy_new_for_bus_finish (res, &error);
+  g_signal_connect (item->item_proxy, "g-signal",
+                    G_CALLBACK (sn_item_signal_received), item);
   free_error_and_return_if_cancelled (error);
-  return_and_finish_if_true (item->properties_proxy == NULL);
+  finish_and_return_if_true (item->properties_proxy == NULL);
 
   sn_item_invalidate (item);
 }
@@ -451,7 +449,7 @@ sn_item_item_callback (GObject      *source_object,
 
   item->item_proxy = g_dbus_proxy_new_for_bus_finish (res, &error);
   free_error_and_return_if_cancelled (error);
-  return_and_finish_if_true (item->item_proxy == NULL);
+  finish_and_return_if_true (item->item_proxy == NULL);
 
   context = g_new0 (SubscriptionContext, 1);
   context->connection = g_dbus_proxy_get_connection (item->item_proxy);
@@ -466,10 +464,7 @@ sn_item_item_callback (GObject      *source_object,
                                         sn_item_name_owner_changed,
                                         item, NULL);
   g_object_weak_ref (G_OBJECT (item->item_proxy),
-                     sn_item_subscription_context_ubsubscribe, context);
-
-  g_signal_connect (item->item_proxy, "g-signal",
-                    G_CALLBACK (sn_item_signal_received), item);
+                     sn_item_subscription_context_unsubscribe, context);
 
   g_dbus_proxy_new (g_dbus_proxy_get_connection (item->item_proxy),
                     G_DBUS_PROXY_FLAGS_NONE,
@@ -523,12 +518,11 @@ sn_item_start (SnItem *item)
 
 
 
-static gboolean
-sn_item_perform_invalidate (gpointer user_data)
+void
+sn_item_invalidate (SnItem *item)
 {
-  SnItem *item = user_data;
-
-  item->properties_timeout = 0;
+  g_return_if_fail (XFCE_IS_SN_ITEM (item));
+  g_return_if_fail (item->properties_proxy != NULL);
 
   g_dbus_proxy_call (item->properties_proxy,
                      "GetAll",
@@ -538,22 +532,6 @@ sn_item_perform_invalidate (gpointer user_data)
                      item->cancellable,
                      sn_item_get_all_properties_result,
                      item);
-
-  return G_SOURCE_REMOVE;
-}
-
-
-
-void
-sn_item_invalidate (SnItem *item)
-{
-  g_return_if_fail (XFCE_IS_SN_ITEM (item));
-  g_return_if_fail (item->properties_proxy != NULL);
-
-  /* same approach as in Plasma Workspace */
-  if (item->properties_timeout != 0)
-    g_source_remove (item->properties_timeout);
-  item->properties_timeout = g_timeout_add (10, sn_item_perform_invalidate, item);
 }
 
 
@@ -733,7 +711,7 @@ sn_item_get_all_properties_result (GObject      *source_object,
 
   properties = g_dbus_proxy_call_finish (G_DBUS_PROXY (source_object), res, &error);
   free_error_and_return_if_cancelled (error);
-  return_and_finish_if_true (properties == NULL);
+  finish_and_return_if_true (properties == NULL);
 
   #define string_empty_null(s) ((s) != NULL ? (s) : "")
 
@@ -1056,7 +1034,8 @@ GtkWidget *
 sn_item_get_menu (SnItem *item)
 {
   #ifdef HAVE_DBUSMENU
-  DbusmenuGtkMenu *menu;
+  DbusmenuGtkMenu   *menu;
+  DbusmenuGtkClient *client;
 
   g_return_val_if_fail (XFCE_IS_SN_ITEM (item), NULL);
   g_return_val_if_fail (item->initialized, NULL);
@@ -1066,6 +1045,8 @@ sn_item_get_menu (SnItem *item)
       menu = dbusmenu_gtkmenu_new (item->bus_name, item->menu_object_path);
       if (menu != NULL)
         {
+          client = dbusmenu_gtkmenu_get_client (menu);
+          dbusmenu_gtkclient_set_accel_group (client, gtk_accel_group_new ());
           g_object_ref_sink (menu);
           item->cached_menu = GTK_WIDGET (menu);
         }
